@@ -25,7 +25,6 @@
 #include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
-#include <locale.h>
 
 #include <glib/gi18n.h>
 #include <gio/gio.h>
@@ -84,17 +83,18 @@ struct _GeditAppPrivate
 
 	PeasExtensionSet  *extensions;
 	GNetworkMonitor   *monitor;
-};
 
-static gboolean new_window = FALSE;
-static gboolean new_document = FALSE;
-static gchar *geometry = NULL;
-static const GtkSourceEncoding *encoding = NULL;
-static GInputStream *stdin_stream = NULL;
-static GSList *file_list = NULL;
-static gint line_position = 0;
-static gint column_position = 0;
-static GApplicationCommandLine *command_line = NULL;
+	/* command line parsing */
+	gboolean new_window;
+	gboolean new_document;
+	gchar *geometry;
+	const GtkSourceEncoding *encoding;
+	GInputStream *stdin_stream;
+	GSList *file_list;
+	gint line_position;
+	gint column_position;
+	GApplicationCommandLine *command_line;
+};
 
 static const GOptionEntry options[] =
 {
@@ -385,27 +385,6 @@ extension_removed (PeasExtensionSet *extensions,
 	gedit_app_activatable_deactivate (GEDIT_APP_ACTIVATABLE (exten));
 }
 
-static gboolean
-gedit_app_has_app_menu (GeditApp *app)
-{
-	GtkSettings *gtk_settings;
-	gboolean show_app_menu;
-	gboolean show_menubar;
-
-	/* We have three cases:
-	 * - GNOME 3: show-app-menu true, show-menubar false -> use the app menu
-	 * - Unity, OSX: show-app-menu and show-menubar true -> use the normal menu
-	 * - Other WM, Windows: show-app-menu and show-menubar false -> use the normal menu
-	 */
-	gtk_settings = gtk_settings_get_default ();
-	g_object_get (G_OBJECT (gtk_settings),
-	              "gtk-shell-shows-app-menu", &show_app_menu,
-	              "gtk-shell-shows-menubar", &show_menubar,
-	              NULL);
-
-	return show_app_menu && !show_menubar;
-}
-
 static void
 load_accels (void)
 {
@@ -502,17 +481,6 @@ gedit_app_startup (GApplication *application)
 	gedit_debug_init ();
 	gedit_debug_message (DEBUG_APP, "Startup");
 
-	gedit_dirs_init ();
-
-	/* Setup locale/gettext */
-	setlocale (LC_ALL, "");
-
-	dir = gedit_dirs_get_gedit_locale_dir ();
-	bindtextdomain (GETTEXT_PACKAGE, dir);
-
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-	textdomain (GETTEXT_PACKAGE);
-
 	gedit_debug_message (DEBUG_APP, "Set icon");
 
 	dir = gedit_dirs_get_gedit_data_dir ();
@@ -541,18 +509,10 @@ gedit_app_startup (GApplication *application)
 	                                 app);
 
 	/* menus */
-	if (gedit_app_has_app_menu (app))
-	{
-		app->priv->window_menu = get_menu_model (app, "gear_menu_withappmenu");
-	}
-	else
-	{
-		app->priv->window_menu = get_menu_model (app, "gear_menu_noappmenu");
-	}
-
-	app->priv->notebook_menu = get_menu_model (app, "notebook_menu");
-	app->priv->tab_width_menu = get_menu_model (app, "tab_width_menu");
-	app->priv->line_col_menu = get_menu_model (app, "line_col_menu");
+	app->priv->window_menu = get_menu_model (app, "gear-menu");
+	app->priv->notebook_menu = get_menu_model (app, "notebook-menu");
+	app->priv->tab_width_menu = get_menu_model (app, "tab-width-menu");
+	app->priv->line_col_menu = get_menu_model (app, "line-col-menu");
 
 	/* Accelerators */
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
@@ -751,16 +711,26 @@ get_active_window (GtkApplication *app)
 }
 
 static void
-set_command_line_wait (GeditTab *tab)
+set_command_line_wait (GeditApp *app,
+		       GeditTab *tab)
 {
 	g_object_set_data_full (G_OBJECT (tab),
 	                        "GeditTabCommandLineWait",
-	                        g_object_ref (command_line),
+	                        g_object_ref (app->priv->command_line),
 	                        (GDestroyNotify)g_object_unref);
 }
 
 static void
-gedit_app_activate (GApplication *application)
+open_files (GApplication            *application,
+	    gboolean                 new_window,
+	    gboolean                 new_document,
+	    gchar                   *geometry,
+	    gint                     line_position,
+	    gint                     column_position,
+	    const GtkSourceEncoding *encoding,
+	    GInputStream            *stdin_stream,
+	    GSList                  *file_list,
+	    GApplicationCommandLine *command_line)
 {
 	GeditWindow *window = NULL;
 	GeditTab *tab;
@@ -782,8 +752,7 @@ gedit_app_activate (GApplication *application)
 
 	if (geometry)
 	{
-		gtk_window_parse_geometry (GTK_WINDOW (window),
-		                           geometry);
+		gtk_window_parse_geometry (GTK_WINDOW (window), geometry);
 	}
 
 	if (stdin_stream)
@@ -800,7 +769,8 @@ gedit_app_activate (GApplication *application)
 
 		if (doc_created && command_line)
 		{
-			set_command_line_wait (tab);
+			set_command_line_wait (GEDIT_APP (application),
+					       tab);
 		}
 		g_input_stream_close (stdin_stream, NULL, NULL);
 	}
@@ -832,7 +802,8 @@ gedit_app_activate (GApplication *application)
 
 		if (command_line)
 		{
-			set_command_line_wait (tab);
+			set_command_line_wait (GEDIT_APP (application),
+					       tab);
 		}
 	}
 
@@ -840,20 +811,39 @@ gedit_app_activate (GApplication *application)
 }
 
 static void
-clear_options (void)
+gedit_app_activate (GApplication *application)
 {
-	g_free (geometry);
-	g_clear_object (&stdin_stream);
-	g_slist_free_full (file_list, g_object_unref);
+	GeditAppPrivate *priv = GEDIT_APP (application)->priv;
 
-	new_window = FALSE;
-	new_document = FALSE;
-	geometry = NULL;
-	encoding = NULL;
-	file_list = NULL;
-	line_position = 0;
-	column_position = 0;
-	command_line = NULL;
+	open_files (application,
+	            priv->new_window,
+	            priv->new_document,
+	            priv->geometry,
+	            priv->line_position,
+	            priv->column_position,
+	            priv->encoding,
+	            priv->stdin_stream,
+	            priv->file_list,
+	            priv->command_line);
+}
+
+static void
+clear_options (GeditApp *app)
+{
+	GeditAppPrivate *priv = app->priv;
+
+	g_free (priv->geometry);
+	g_clear_object (&priv->stdin_stream);
+	g_slist_free_full (priv->file_list, g_object_unref);
+
+	priv->new_window = FALSE;
+	priv->new_document = FALSE;
+	priv->geometry = NULL;
+	priv->encoding = NULL;
+	priv->file_list = NULL;
+	priv->line_position = 0;
+	priv->column_position = 0;
+	priv->command_line = NULL;
 }
 
 static void
@@ -885,26 +875,29 @@ static gint
 gedit_app_command_line (GApplication            *application,
                         GApplicationCommandLine *cl)
 {
+	GeditAppPrivate *priv;
 	GVariantDict *options;
 	const gchar *encoding_charset;
 	const gchar **remaining_args;
 
+	priv = GEDIT_APP (application)->priv;
+
 	options = g_application_command_line_get_options_dict (cl);
 
-	g_variant_dict_lookup (options, "new-window", "b", &new_window);
-	g_variant_dict_lookup (options, "new-document", "b", &new_document);
-	g_variant_dict_lookup (options, "geometry", "s", &geometry);
+	g_variant_dict_lookup (options, "new-window", "b", &priv->new_window);
+	g_variant_dict_lookup (options, "new-document", "b", &priv->new_document);
+	g_variant_dict_lookup (options, "geometry", "s", &priv->geometry);
 
 	if (g_variant_dict_contains (options, "wait"))
 	{
-		command_line = cl;
+		priv->command_line = cl;
 	}
 
 	if (g_variant_dict_lookup (options, "encoding", "&s", &encoding_charset))
 	{
-		encoding = gtk_source_encoding_get_from_charset (encoding_charset);
+		priv->encoding = gtk_source_encoding_get_from_charset (encoding_charset);
 
-		if (encoding == NULL)
+		if (priv->encoding == NULL)
 		{
 			g_application_command_line_printerr (cl,
 							     _("%s: invalid encoding."),
@@ -924,35 +917,35 @@ gedit_app_command_line (GApplication            *application,
 				if (*(remaining_args[i] + 1) == '\0')
 				{
 					/* goto the last line of the document */
-					line_position = G_MAXINT;
-					column_position = 0;
+					priv->line_position = G_MAXINT;
+					priv->column_position = 0;
 				}
 				else
 				{
 					get_line_column_position (remaining_args[i] + 1,
-								  &line_position,
-								  &column_position);
+								  &priv->line_position,
+								  &priv->column_position);
 				}
 			}
 			else if (*remaining_args[i] == '-' && *(remaining_args[i] + 1) == '\0')
 			{
-				stdin_stream = g_application_command_line_get_stdin (cl);
+				priv->stdin_stream = g_application_command_line_get_stdin (cl);
 			}
 			else
 			{
 				GFile *file;
 
 				file = g_application_command_line_create_file_for_arg (cl, remaining_args[i]);
-				file_list = g_slist_prepend (file_list, file);
+				priv->file_list = g_slist_prepend (priv->file_list, file);
 			}
 		}
 
-		file_list = g_slist_reverse (file_list);
+		priv->file_list = g_slist_reverse (priv->file_list);
 		g_free (remaining_args);
 	}
 
 	g_application_activate (application);
-	clear_options ();
+	clear_options (GEDIT_APP (application));
 
 	return 0;
 }
@@ -999,6 +992,42 @@ gedit_app_handle_local_options (GApplication *application,
 	return -1;
 }
 
+/* Note: when launched from command line we do not reach this method
+ * since we manually handle the command line parameters in order to
+ * parse +LINE:COL, stdin, etc.
+ * However this method is called when open() is called via dbus, for
+ * instance when double clicking on a file in nautilus
+ */
+static void
+gedit_app_open (GApplication  *application,
+                GFile        **files,
+                gint           n_files,
+                const gchar   *hint)
+{
+	gint i;
+	GSList *file_list = NULL;
+
+	for (i = 0; i < n_files; i++)
+	{
+		file_list = g_slist_prepend (file_list, files[i]);
+	}
+
+	file_list = g_slist_reverse (file_list);
+
+	open_files (application,
+	            FALSE,
+	            FALSE,
+	            NULL,
+	            0,
+	            0,
+	            NULL,
+	            NULL,
+	            file_list,
+	            NULL);
+
+	g_slist_free (file_list);
+}
+
 static gboolean
 ensure_user_config_dir (void)
 {
@@ -1193,6 +1222,7 @@ gedit_app_class_init (GeditAppClass *klass)
 	app_class->activate = gedit_app_activate;
 	app_class->command_line = gedit_app_command_line;
 	app_class->handle_local_options = gedit_app_handle_local_options;
+	app_class->open = gedit_app_open;
 	app_class->shutdown = gedit_app_shutdown;
 
 	klass->show_help = gedit_app_show_help_impl;
