@@ -1520,9 +1520,11 @@ _gedit_tab_get_tooltip (GeditTab *tab)
 			enc = gtk_source_file_get_encoding (file);
 
 			if (enc == NULL)
-				encoding = g_strdup (_("Unicode (UTF-8)"));
-			else
-				encoding = gtk_source_encoding_to_string (enc);
+			{
+				enc = gtk_source_encoding_get_utf8 ();
+			}
+
+			encoding = gtk_source_encoding_to_string (enc);
 
 			tip =  g_markup_printf_escaped ("<b>%s</b> %s\n\n"
 						        "<b>%s</b> %s\n"
@@ -2432,7 +2434,6 @@ _gedit_tab_save_as (GeditTab                 *tab,
 	GeditDocument *doc;
 	GtkSourceFile *file;
 	GtkSourceFileSaverFlags save_flags;
-	GFile *prev_location;
 
 	g_return_if_fail (GEDIT_IS_TAB (tab));
 	g_return_if_fail (tab->priv->state == GEDIT_TAB_STATE_NORMAL ||
@@ -2468,16 +2469,6 @@ _gedit_tab_save_as (GeditTab                 *tab,
 
 	file = gedit_document_get_file (doc);
 
-	prev_location = gtk_source_file_get_location (file);
-
-	if (prev_location == NULL ||
-	    !g_file_equal (prev_location, location))
-	{
-		/* Ignore modification time for a save to another location. */
-		/* TODO do that in GtkSourceFileSaver. */
-		save_flags |= GTK_SOURCE_FILE_SAVER_FLAGS_IGNORE_MODIFICATION_TIME;
-	}
-
 	tab->priv->saver = gtk_source_file_saver_new_with_target (GTK_SOURCE_BUFFER (doc),
 								  file,
 								  location);
